@@ -66,6 +66,13 @@ class LatexArticle:
             return self.version.date or self.version.date_created
         return None
 
+    def oxalink(self, base: str):
+        if self.version is None:
+            return None
+        v = self.version
+        return f"{base}/oxa:{v.id.project}/{v.id.block}.{v.id.version}"
+
+
     def fetch(self, version: Optional[int] = None):
         """Download article and all children in Latex format
 
