@@ -15,11 +15,9 @@ logger = logging.getLogger()
 LANG = "___LANG___"
 CODE_CONTENT = "___CODE_CONTENT___"
 
-CODE_BLOCK_TPL = rf"""\begin{{framed}}
-\begin{{minted}}[tabsize=4, linenos, mathescape, numbersep=5pt, framesep=2mm, fontsize=\scriptsize]{{{LANG}}}
+CODE_BLOCK_TPL = rf"""\begin{{minted}}[tabsize=4, linenos, mathescape, numbersep=5pt, framesep=2mm]{{{LANG}}}
 {CODE_CONTENT}
 \end{{minted}}
-\end{{framed}}
 """
 
 
@@ -74,7 +72,6 @@ class LatexBlockVersion:
             logger.info("Found: Code Block - wrapping content in minted")
             content = CODE_BLOCK_TPL.replace(
                 LANG, "python").replace(CODE_CONTENT, self.version.content)
-            logger.info(content)
         elif kind == BlockKind.image:
             logger.info("Found: Top Level Image Block")
             try:
