@@ -1,4 +1,4 @@
-from curvenote.latex.utils.imagemagick import check_for_imagemagick, convert_gif
+from curvenote.latex.utils.imagemagick import convert_gif
 import logging
 import os
 
@@ -42,8 +42,8 @@ def get_image_block(
     if content_type == "image/gif":
         logging.info("Found image/gif converting to image/png")
         # convert to png, leave gif file in place but return the png path for use in content
-        check_for_imagemagick()
-        local_path_with_extension = convert_gif(local_path_with_extension)
+        local_path_with_extension = convert_gif(assets_folder, local_path_with_extension)
+        logging.info(f"Updated local path: {local_path_with_extension}")
         # either calls will raise exception on error causing file to be skipped
 
     return image_block, local_path_with_extension
