@@ -180,6 +180,7 @@ class BlockChildID(BaseModel):
 class BlockFormat(str, Enum):
     """"""
 
+    txt = "txt"
     html = "html"
     md = "md"
     jupyter = "jupyter"
@@ -314,6 +315,8 @@ class BlockVersion(BaseModel):
     size: Optional[int]
     content_type: Optional[str]
     md5: Optional[str]
+    caption: Optional[str]
+    file_name: Optional[str]
 
     # Kind: Article
     date: Optional[datetime]
